The macro implementation for target-test-dir

Use the target-test-dir crate rather than this, which has runtime support as well as complete docs.

Attribute Macros

Annotate a test function which takes a single std::path::PathBuf argument which will be a freshly created directory